export namespace PDFViewerApplication {
    export const initialBookmark: string;
    export const _initializedCapability: any;
    export const fellback: boolean;
    export const appConfig: null;
    export const pdfDocument: null;
    export const pdfLoadingTask: null;
    export const printService: null;
    export const pdfViewer: PDFViewer;
    export const pdfThumbnailViewer: PDFThumbnailViewer;
    export const pdfRenderingQueue: PDFRenderingQueue;
    export const pdfPresentationMode: PDFPresentationMode;
    export const pdfDocumentProperties: PDFDocumentProperties;
    export const pdfLinkService: PDFLinkService;
    export const pdfHistory: PDFHistory;
    export const pdfSidebar: PDFSidebar;
    export const pdfSidebarResizer: PDFSidebarResizer;
    export const pdfOutlineViewer: PDFOutlineViewer;
    export const pdfAttachmentViewer: PDFAttachmentViewer;
    export const pdfLayerViewer: PDFLayerViewer;
    export const pdfCursorTools: PDFCursorTools;
    export const store: ViewHistory;
    export const downloadManager: any;
    export const overlayManager: OverlayManager;
    export const preferences: any;
    export const toolbar: Toolbar;
    export const secondaryToolbar: SecondaryToolbar;
    export const eventBus: EventBus;
    export const l10n: any;
    export const isInitialViewSet: boolean;
    export const downloadComplete: boolean;
    export const isViewerEmbedded: boolean;
    export const url: string;
    export const baseUrl: string;
    export { DefaultExternalServices as externalServices };
    export const _boundEvents: {};
    export const contentDispositionFilename: null;
    export const triggerDelayedFallback: null;
    export const _saveInProgress: boolean;
    export const _wheelUnusedTicks: number;
    export function initialize(appConfig: any): Promise<void>;
    export function initialize(appConfig: any): Promise<void>;
    /**
     * @private
     */
    export function _readPreferences(): Promise<void>;
    /**
     * @private
     */
    export function _readPreferences(): Promise<void>;
    /**
     * Potentially parse special debugging flags in the hash section of the URL.
     * @private
     */
    export function _parseHashParameters(): Promise<void | any[]>;
    /**
     * Potentially parse special debugging flags in the hash section of the URL.
     * @private
     */
    export function _parseHashParameters(): Promise<void | any[]>;
    /**
     * @private
     */
    export function _initializeL10n(): Promise<void>;
    /**
     * @private
     */
    export function _initializeL10n(): Promise<void>;
    /**
     * @private
     */
    export function _initializeViewerComponents(): Promise<void>;
    /**
     * @private
     */
    export function _initializeViewerComponents(): Promise<void>;
    /**
     * @property {{ disableDrop: boolean }} additionalConfig
     */
    export function run(config: any): void;
    /**
     * @property {{ disableDrop: boolean }} additionalConfig
     */
    export function run(config: any): void;
    export function zoomIn(ticks: any): void;
    export function zoomIn(ticks: any): void;
    export function zoomOut(ticks: any): void;
    export function zoomOut(ticks: any): void;
    export function zoomReset(): void;
    export function zoomReset(): void;
    export function initPassiveLoading(): void;
    export function initPassiveLoading(): void;
    export function setTitleUsingUrl(url?: string): void;
    export function setTitleUsingUrl(url?: string): void;
    export function setTitle(title: any): void;
    export function setTitle(title: any): void;
    /**
     * Closes opened PDF document.
     * @returns {Promise} - Returns the promise, which is resolved when all
     *                      destruction is completed.
     */
    export function close(): Promise<any>;
    /**
     * Closes opened PDF document.
     * @returns {Promise} - Returns the promise, which is resolved when all
     *                      destruction is completed.
     */
    export function close(): Promise<any>;
    /**
     * Opens PDF document specified by URL or array with additional arguments.
     * @param {string|TypedArray|ArrayBuffer} file - PDF location or binary data.
     * @param {Object} [args] - Additional arguments for the getDocument call,
     *                          e.g. HTTP headers ('httpHeaders') or alternative
     *                          data transport ('range').
     * @returns {Promise} - Returns the promise, which is resolved when document
     *                      is opened.
     */
    export function open(file: any, args?: Object | undefined): Promise<any>;
    /**
     * Opens PDF document specified by URL or array with additional arguments.
     * @param {string|TypedArray|ArrayBuffer} file - PDF location or binary data.
     * @param {Object} [args] - Additional arguments for the getDocument call,
     *                          e.g. HTTP headers ('httpHeaders') or alternative
     *                          data transport ('range').
     * @returns {Promise} - Returns the promise, which is resolved when document
     *                      is opened.
     */
    export function open(file: any, args?: Object | undefined): Promise<any>;
    export function download({ sourceEventType }?: {
        sourceEventType?: string | undefined;
    }): void;
    export function download({ sourceEventType }?: {
        sourceEventType?: string | undefined;
    }): void;
    export function save({ sourceEventType }?: {
        sourceEventType?: string | undefined;
    }): void;
    export function save({ sourceEventType }?: {
        sourceEventType?: string | undefined;
    }): void;
    /**
     * For PDF documents that contain e.g. forms and javaScript, we should only
     * trigger the fallback bar once the user has interacted with the page.
     * @private
     */
    export function _delayedFallback(featureId: any): void;
    /**
     * For PDF documents that contain e.g. forms and javaScript, we should only
     * trigger the fallback bar once the user has interacted with the page.
     * @private
     */
    export function _delayedFallback(featureId: any): void;
    export function fallback(featureId: any): void;
    export function fallback(featureId: any): void;
    /**
     * Show the error box.
     * @param {string} message - A message that is human readable.
     * @param {Object} [moreInfo] - Further information about the error that is
     *                              more technical.  Should have a 'message' and
     *                              optionally a 'stack' property.
     */
    export function error(message: string, moreInfo?: Object | undefined): void;
    /**
     * Show the error box.
     * @param {string} message - A message that is human readable.
     * @param {Object} [moreInfo] - Further information about the error that is
     *                              more technical.  Should have a 'message' and
     *                              optionally a 'stack' property.
     */
    export function error(message: string, moreInfo?: Object | undefined): void;
    export function progress(level: any): void;
    export function progress(level: any): void;
    export function load(pdfDocument: any): void;
    export function load(pdfDocument: any): void;
    /**
     * @private
     */
    export function _initializeAutoPrint(pdfDocument: any, openActionPromise: any): Promise<void>;
    /**
     * @private
     */
    export function _initializeAutoPrint(pdfDocument: any, openActionPromise: any): Promise<void>;
    /**
     * @private
     */
    export function _initializeMetadata(pdfDocument: any): Promise<void>;
    /**
     * @private
     */
    export function _initializeMetadata(pdfDocument: any): Promise<void>;
    /**
     * @private
     */
    export function _initializePageLabels(pdfDocument: any): Promise<void>;
    /**
     * @private
     */
    export function _initializePageLabels(pdfDocument: any): Promise<void>;
    /**
     * @private
     */
    export function _initializePdfHistory({ fingerprint, viewOnLoad, initialDest }: {
        fingerprint: any;
        viewOnLoad: any;
        initialDest?: any;
    }): void;
    /**
     * @private
     */
    export function _initializePdfHistory({ fingerprint, viewOnLoad, initialDest }: {
        fingerprint: any;
        viewOnLoad: any;
        initialDest?: any;
    }): void;
    /**
     * @private
     */
    export function _initializePermissions(pdfDocument: any): Promise<void>;
    /**
     * @private
     */
    export function _initializePermissions(pdfDocument: any): Promise<void>;
    export function setInitialView(storedHash: any, { rotation, sidebarView, scrollMode, spreadMode }?: {
        rotation: any;
        sidebarView: any;
        scrollMode: any;
        spreadMode: any;
    }): void;
    export function setInitialView(storedHash: any, { rotation, sidebarView, scrollMode, spreadMode }?: {
        rotation: any;
        sidebarView: any;
        scrollMode: any;
        spreadMode: any;
    }): void;
    export function cleanup(): void;
    export function cleanup(): void;
    export function forceRendering(): void;
    export function forceRendering(): void;
    export function beforePrint(): void;
    export function beforePrint(): void;
    export function afterPrint(): void;
    export function afterPrint(): void;
    export function rotatePages(delta: any): void;
    export function rotatePages(delta: any): void;
    export function requestPresentationMode(): void;
    export function requestPresentationMode(): void;
    export function bindEvents(): void;
    export function bindEvents(): void;
    export function bindWindowEvents(): void;
    export function bindWindowEvents(): void;
    export function unbindEvents(): void;
    export function unbindEvents(): void;
    export function unbindWindowEvents(): void;
    export function unbindWindowEvents(): void;
    export function accumulateWheelTicks(ticks: any): number;
    export function accumulateWheelTicks(ticks: any): number;
}
export class DefaultExternalServices {
    static updateFindControlState(data: any): void;
    static updateFindMatchesCount(data: any): void;
    static initPassiveLoading(callbacks: any): void;
    static fallback(data: any, callback: any): void;
    static reportTelemetry(data: any): void;
    static createDownloadManager(options: any): void;
    static createPreferences(): void;
    static createL10n(options: any): void;
    static get supportsIntegratedFind(): any;
    static get supportsDocumentFonts(): any;
    static get supportedMouseWheelZoomModifierKeys(): any;
    static get isInAutomation(): any;
}
export namespace PDFPrintServiceFactory {
    namespace instance {
        const supportsPrinting: boolean;
        function createPrintService(): never;
        function createPrintService(): never;
    }
}
import { PDFViewer } from "./pdf_viewer.js";
import { PDFThumbnailViewer } from "./pdf_thumbnail_viewer.js";
import { PDFRenderingQueue } from "./pdf_rendering_queue.js";
import { PDFPresentationMode } from "./pdf_presentation_mode.js";
import { PDFDocumentProperties } from "./pdf_document_properties.js";
import { PDFLinkService } from "./pdf_link_service.js";
import { PDFHistory } from "./pdf_history.js";
import { PDFSidebar } from "./pdf_sidebar.js";
import { PDFSidebarResizer } from "./pdf_sidebar_resizer.js";
import { PDFOutlineViewer } from "./pdf_outline_viewer.js";
import { PDFAttachmentViewer } from "./pdf_attachment_viewer.js";
import { PDFLayerViewer } from "./pdf_layer_viewer.js";
import { PDFCursorTools } from "./pdf_cursor_tools.js";
import { ViewHistory } from "./view_history.js";
import { OverlayManager } from "./overlay_manager.js";
import { Toolbar } from "./toolbar.js";
import { SecondaryToolbar } from "./secondary_toolbar.js";
import { EventBus } from "./ui_utils.js";
//# sourceMappingURL=app.d.ts.map