export type PDFDocumentPropertiesOptions = {
    /**
     * - Name/identifier for the overlay.
     */
    overlayName: string;
    /**
     * - Names and elements of the overlay's fields.
     */
    fields: Object;
    /**
     * - Div container for the overlay.
     */
    container: HTMLDivElement;
    /**
     * - Button for closing the overlay.
     */
    closeButton: HTMLButtonElement;
};
/**
 * @typedef {Object} PDFDocumentPropertiesOptions
 * @property {string} overlayName - Name/identifier for the overlay.
 * @property {Object} fields - Names and elements of the overlay's fields.
 * @property {HTMLDivElement} container - Div container for the overlay.
 * @property {HTMLButtonElement} closeButton - Button for closing the overlay.
 */
export class PDFDocumentProperties {
    /**
     * @param {PDFDocumentPropertiesOptions} options
     * @param {OverlayManager} overlayManager - Manager for the viewer overlays.
     * @param {EventBus} eventBus - The application event bus.
     * @param {IL10n} l10n - Localization service.
     */
    constructor({ overlayName, fields, container, closeButton }: PDFDocumentPropertiesOptions, overlayManager: any, eventBus: any, l10n?: any);
    overlayName: string;
    fields: Object;
    container: HTMLDivElement;
    overlayManager: any;
    l10n: any;
    _currentPageNumber: any;
    _pagesRotation: any;
    _isNonMetricLocale: boolean;
    /**
     * Open the document properties overlay.
     */
    open(): void;
    maybeFileSize: any;
    /**
     * Close the document properties overlay.
     */
    close(): void;
    /**
     * Set a reference to the PDF document and the URL in order
     * to populate the overlay fields with the document properties.
     * Note that the overlay will contain no information if this method
     * is not called.
     *
     * @param {PDFDocumentProxy} pdfDocument - A reference to the PDF document.
     * @param {string} url - The URL of the document.
     */
    setDocument(pdfDocument: any, url?: string): void;
    pdfDocument: any;
    url: string | null | undefined;
    /**
     * Set the file size of the PDF document. This method is used to
     * update the file size in the document properties overlay once it
     * is known so we do not have to wait until the entire file is loaded.
     *
     * @param {number} fileSize - The file size of the PDF document.
     */
    setFileSize(fileSize: number): void;
    /**
     * @private
     */
    private _reset;
    _dataAvailableCapability: any;
    /**
     * Always updates all of the dialog fields, to prevent inconsistent UI state.
     * NOTE: If the contents of a particular field is neither a non-empty string,
     *       nor a number, it will fall back to `DEFAULT_FIELD_CONTENT`.
     * @private
     */
    private _updateUI;
    /**
     * @private
     */
    private _parseFileSize;
    /**
     * @private
     */
    private _parsePageSize;
    /**
     * @private
     */
    private _parseDate;
    /**
     * @private
     */
    private _parseLinearization;
}
//# sourceMappingURL=pdf_document_properties.d.ts.map