export type PDFPresentationModeOptions = {
    /**
     * - The container for the viewer element.
     */
    container: HTMLDivElement;
    /**
     * - The document viewer.
     */
    pdfViewer: any;
    /**
     * - The application event bus.
     */
    eventBus: any;
    /**
     * - The menu items that are added to the
     * context menu in Presentation Mode.
     */
    contextMenuItems?: any[] | undefined;
};
/**
 * @typedef {Object} PDFPresentationModeOptions
 * @property {HTMLDivElement} container - The container for the viewer element.
 * @property {PDFViewer} pdfViewer - The document viewer.
 * @property {EventBus} eventBus - The application event bus.
 * @property {Array} [contextMenuItems] - The menu items that are added to the
 *   context menu in Presentation Mode.
 */
export class PDFPresentationMode {
    /**
     * @param {PDFPresentationModeOptions} options
     */
    constructor({ container, pdfViewer, eventBus, contextMenuItems }: PDFPresentationModeOptions);
    container: HTMLDivElement;
    pdfViewer: any;
    eventBus: any;
    active: boolean;
    args: {
        page: any;
        previousScale: any;
    } | null;
    contextMenuOpen: boolean;
    mouseScrollTimeStamp: number;
    mouseScrollDelta: number;
    touchSwipeState: {
        startX: any;
        startY: any;
        endX: any;
        endY: any;
    } | null;
    /**
     * Request the browser to enter fullscreen mode.
     * @returns {boolean} Indicating if the request was successful.
     */
    request(): boolean;
    /**
     * @private
     */
    private _mouseWheel;
    get isFullscreen(): boolean;
    /**
     * @private
     */
    private _goToPreviousPage;
    /**
     * @private
     */
    private _goToNextPage;
    /**
     * @private
     */
    private _notifyStateChange;
    /**
     * Used to initialize a timeout when requesting Presentation Mode,
     * i.e. when the browser is requested to enter fullscreen mode.
     * This timeout is used to prevent the current page from being scrolled
     * partially, or completely, out of view when entering Presentation Mode.
     * NOTE: This issue seems limited to certain zoom levels (e.g. page-width).
     *
     * @private
     */
    private _setSwitchInProgress;
    switchInProgress: any;
    /**
     * @private
     */
    private _resetSwitchInProgress;
    /**
     * @private
     */
    private _enter;
    /**
     * @private
     */
    private _exit;
    /**
     * @private
     */
    private _mouseDown;
    /**
     * @private
     */
    private _contextMenu;
    /**
     * @private
     */
    private _showControls;
    controlsTimeout: any;
    /**
     * @private
     */
    private _hideControls;
    /**
     * Resets the properties used for tracking mouse scrolling events.
     *
     * @private
     */
    private _resetMouseScrollState;
    /**
     * @private
     */
    private _touchSwipe;
    /**
     * @private
     */
    private _addWindowListeners;
    showControlsBind: (() => void) | undefined;
    mouseDownBind: ((evt: any) => void) | undefined;
    mouseWheelBind: ((evt: any) => void) | undefined;
    resetMouseScrollStateBind: (() => void) | undefined;
    contextMenuBind: (() => void) | undefined;
    touchSwipeBind: ((evt: any) => void) | undefined;
    /**
     * @private
     */
    private _removeWindowListeners;
    /**
     * @private
     */
    private _fullscreenChange;
    /**
     * @private
     */
    private _addFullscreenChangeListeners;
    fullscreenChangeBind: (() => void) | undefined;
    /**
     * @private
     */
    private _removeFullscreenChangeListeners;
}
//# sourceMappingURL=pdf_presentation_mode.d.ts.map